/*******************************************************************************
 *
 * Copyright (c) 2016-2026 HYCON Technology, Inc.
 * All rights reserved.
 * HYCON Technology <www.hycontek.com>
 *
 * HYCON reserves the right to amend this code without notice at any time.
 * HYCON assumes no responsibility for any errors appeared in the code,
 * and HYCON disclaims any express or implied warranty, relating to sale
 * and/or use of this code including liability or warranties relating
 * to fitness for a particular purpose, or infringement of any patent,
 * copyright or other intellectual property right.
 *
 * -----------------------------------------------------------------------------
 * Project Name : HY16F021V01 ( Pricing Scale )
 * IDE tooling  : AndeSight C/C++ IDE, version: 2.0.1 Build ID : 201303201736
 * Device Ver.  : V0.9 crt0.o for HY16F19xx & HY16F18xx MCU.
 * Library Ver. : 1.1
 * MCU Device   : HY16F198B-L100 @3.0V
 * Description  : This file implements the customer's function.
 * Created Date : 2016/05/28
 * Created by   :
 *
 ******************************************************************************/

/*----------------------------------------------------------------------------*/
/* Header file include                                                        */
/*----------------------------------------------------------------------------*/
#include "HY16F198.h"
#include "System.h"
#include "ModuleID.h"
#include "SpecialMacro.h"
#include "Sysinfra.h"
#include "DrvClock.h"
#include "DrvGPIO.h"
#include "DrvLCD.h"
#include "DrvREG32.h"
#include "DrvADC.h"
#include "DrvTimer.h"
#include "DrvUART.h"
#include "user_DEF.h"
//#include "user_LCD.h"

/*----------------------------------------------------------------------------*/
/* Structure definition                                                       */
/*----------------------------------------------------------------------------*/
volatile typedef union _MCUSTATUS
{
    char  _byte;
    struct
    {
        unsigned b_ADCdone:1;
        unsigned b_TMAdone:1;
        unsigned b_TMBdone:1;
        unsigned b_TMC0done:1;
        unsigned b_TMC1done:1;
        unsigned b_RTCdone:1;
        unsigned b_UART_TxDone:1;
        unsigned b_UART_RxDone:1;
    };
} MCUSTATUS;

/*----------------------------------------------------------------------------*/
/* Global variable definition                                                 */
/*----------------------------------------------------------------------------*/
MCUSTATUS  MCUSTATUSbits;

/*----------------------------------------------------------------------------*/
/* Constant value definition                                                  */
/*----------------------------------------------------------------------------*/

/*----------------------------------------------------------------------------*/
/* Function prototype declaration                                             */
/*----------------------------------------------------------------------------*/

/*----------------------------------------------------------------------------*/
/* MAIN  function                                                             */
/*----------------------------------------------------------------------------*/
int main(void)
{
    unsigned char scan_idx = 0;

    User_Sample_Init();

    //Enter Main program loop
    while(1)
    {
        //User task initial going ?
        if ( UserFlag0.b_InitGo_Flag == TRUE )
            PowerOn_Init_Go();

        //System enter SLEEP mode ?
        if ( UserFlag0.b_EntSLP_Flag == TRUE )
        {
            Enter_SLEEP_Mode();
            SYS_LowPower(0);                            //vҦ]Sleep mode^
            Release_SLEEP_Mode();
        }

        ADC_RawData_Avg_Process();

        //each task processing period= (base time) * 4tasks = 8mS * 4 = 32mS.
        //
        if( UserFlag0.b_TB8mS_Flag == TRUE )
        {
            UserFlag0.b_TB8mS_Flag = FALSE;
            Key_Scan_Process();                         //4x4 key matrix scanning.
            Beep_Tone_Process();                        //Beep tone process !

            scan_idx = (scan_idx+1) & 0x03;             //keep bit[1:0].
            switch( scan_idx )
            {
                //Key matrix scanning.
                case 0:
                    Key_In_Process();                   //Key in processing.
                 // Check_Cal_Mode_SW();                //Cal. SW scanning!
                    break;
                //Key matrix scanning.
                case 1:
                    Get_Weight_Nums();
                    break;
                //LCD display !
                case 2:
                    LCD_Display_Process();
                    break;
                //Sleep Time Update counting.
                case 3:
                {
                    if ( 2 >= Sleep_Time_Cnt )
                        UserFlag0.b_EntSLP_Flag = TRUE;
                    else
                        Sleep_Time_Cnt--;
                    break;
                }
                default:
                    break;
            }
        DrvWDT_ClearWDT();                              //Clear WDT interrupt flag
        }
    }
    return 0;
}

/*---------------------------------------------------------------------------*/
/* Exception Service Routines                                                */
/*---------------------------------------------------------------------------*/
void tlb_exception_handler()
{
    //procedure define by customer.
    asm("nop");
    asm("nop");
}


/******************************************************************************/
/* File Name    : user_ISR.c                                                  */
/* Description  : This file implements the customer's ISR function.           */
/* Created Date : 2016/05/28                                                  */
/* Created by   :                                                             */
/******************************************************************************/
#if (0)
/*----------------------------------------------------------------------------*/
/* Function Name: HW0_ISR()                                                   */
/* Description  : I2C/UART/SPI interrupt Service Routine (HW0).               */
/* Arguments    : None.                                                       */
/* Return Value : None.                                                       */
/* Remark       :                                                             */
/*----------------------------------------------------------------------------*/
void HW0_ISR(void)
{

}
#endif

#if (1)
/*----------------------------------------------------------------------------*/
/* Function Name: HW1_ISR()                                                   */
/* Description  : WDT & RTC & Timer A/B/C interrupt Service Routine (HW1).    */
/* Arguments    : None.                                                       */
/* Return Value : None.                                                       */
/* Remark       :                                                             */
/*----------------------------------------------------------------------------*/
void HW1_ISR(void)
{

//------TIMER A Int ?---------------------------
    if( DrvTIMER_GetIntFlag( E_TMA ) )
    {
        DrvTIMER_ClearIntFlag( E_TMA );         //Clear TMA interrupt flag
        UserFlag0.b_TB8mS_Flag = TRUE;
    }
}
#endif

#if (1)
/*----------------------------------------------------------------------------*/
/* Function Name: HW2_ISR()                                                   */
/* Description  : ADC interrupt Service Routine (HW2).                        */
/* Arguments    : None.                                                       */
/* Return Value : None.                                                       */
/* Remark       :                                                             */
/*----------------------------------------------------------------------------*/
void HW2_ISR(void)
{
    if( DrvADC_ReadIntFlag() )
    {
        ADC_RawData = DrvADC_GetConversionData();       //get ADC convert data
//      ADC_RawData = ADC_RawData >> 15;                //remain 17bit ADC raw data.
        ADC_RawData = ADC_RawData >> 14;                //remain 18bit ADC raw data.
        DrvADC_ClearIntFlag();                          // clear ADC interrupt flag
        UserFlag1.b_ADC_In_Flag = TRUE;
    }
}
#endif

#if (0)
/*----------------------------------------------------------------------------*/
/* Function Name: HW3_ISR()                                                   */
/* Description  : CMP & OPA interrupt Service Routine (HW3).                  */
/* Arguments    : None.                                                       */
/* Return Value : None.                                                       */
/* Remark       :                                                             */
/*----------------------------------------------------------------------------*/
void HW3_ISR(void)
{
    DrvCMP_ClearIntFlag();                      //Clear CMP interrupt flag
}
#endif

#if (0)
/*----------------------------------------------------------------------------*/
/* Function Name: HW4_ISR()                                                   */
/* Description  : PT1 interrupt Service Routine (HW4).                        */
/* Arguments    : None.                                                       */
/* Return Value : None.                                                       */
/* Remark       :                                                             */
/*----------------------------------------------------------------------------*/
void HW4_ISR(void)
{

}
#endif

#if (0)
/*----------------------------------------------------------------------------*/
/* Function Name: HW5_ISR()                                                   */
/* Description  : PT2 interrupt Service Routine (HW5).                        */
/* Arguments    : None.                                                       */
/* Return Value : None.                                                       */
/* Remark       :                                                             */
/*----------------------------------------------------------------------------*/
void HW5_ISR(void)
{

}
#endif

#if (0)
/*----------------------------------------------------------------------------*/
/* Function Name: HW7_ISR()                                                   */
/* Description  : UART2 interrupt Service Routine (HW7).                      */
/* Arguments    : None.                                                       */
/* Return Value : None.                                                       */
/* Remark       :                                                             */
/*----------------------------------------------------------------------------*/
void HW7_ISR(void)
{

}
#endif

#if (0)
/*----------------------------------------------------------------------------*/
/* Function Name: HW8_ISR()                                                   */
/* Description  : Timer B2 interrupt Service Routine (HW8).                   */
/* Arguments    : None.                                                       */
/* Return Value : None.                                                       */
/* Remark       :                                                             */
/*----------------------------------------------------------------------------*/
void HW8_ISR(void)
{
    if( DrvTIMER_GetIntFlag (E_TMB2) )
    {
        DrvTIMER_ClearIntFlag(E_TMB2);          // Clear TMB interrupt flag
    }
}
#endif

/*----------------------------------------------------------------------------*/
/* End Of File                                                                */
/*----------------------------------------------------------------------------*/
